@@ -68,6 +68,9 @@ new IntegDefaultStack(app, 'gitlab-runner');
 app.synth();
 ```
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -82,7 +85,9 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import cdktf_cdktf_provider_google as _cdktf_cdktf_provider_google_6cd2ae20
+import cdktf_cdktf_provider_google.compute_instance_template as _cdktf_cdktf_provider_google_compute_instance_template_6cd2ae20
+import cdktf_cdktf_provider_google.data_google_compute_network as _cdktf_cdktf_provider_google_data_google_compute_network_6cd2ae20
+import cdktf_cdktf_provider_google.provider as _cdktf_cdktf_provider_google_provider_6cd2ae20
 import constructs as _constructs_77d1e7e8
 
 
@@ -161,9 +166,9 @@ class GitlabRunnerAutoscaling(
         id: builtins.str,
         *,
         gitlab_token: builtins.str,
-        provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
+        provider: _cdktf_cdktf_provider_google_provider_6cd2ae20.GoogleProvider,
         automatic_restart: typing.Optional[builtins.bool] = None,
-        compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
+        compute_network: typing.Optional[_cdktf_cdktf_provider_google_data_google_compute_network_6cd2ae20.DataGoogleComputeNetwork] = None,
         concurrent: typing.Optional[jsii.Number] = None,
         default_disk_size_gb: typing.Optional[jsii.Number] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
@@ -173,7 +178,7 @@ class GitlabRunnerAutoscaling(
         machine_type: typing.Optional[builtins.str] = None,
         network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         preemptible: typing.Optional[builtins.bool] = None,
-        service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
+        service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_compute_instance_template_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -224,9 +229,9 @@ class GitlabRunnerAutoscaling(
         self,
         *,
         gitlab_token: builtins.str,
-        provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
+        provider: _cdktf_cdktf_provider_google_provider_6cd2ae20.GoogleProvider,
         automatic_restart: typing.Optional[builtins.bool] = None,
-        compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
+        compute_network: typing.Optional[_cdktf_cdktf_provider_google_data_google_compute_network_6cd2ae20.DataGoogleComputeNetwork] = None,
         concurrent: typing.Optional[jsii.Number] = None,
         default_disk_size_gb: typing.Optional[jsii.Number] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
@@ -236,7 +241,7 @@ class GitlabRunnerAutoscaling(
         machine_type: typing.Optional[builtins.str] = None,
         network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         preemptible: typing.Optional[builtins.bool] = None,
-        service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
+        service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_compute_instance_template_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> typing.List[builtins.str]:
         '''
@@ -305,9 +310,9 @@ class GitlabRunnerAutoscalingProps:
         self,
         *,
         gitlab_token: builtins.str,
-        provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
+        provider: _cdktf_cdktf_provider_google_provider_6cd2ae20.GoogleProvider,
         automatic_restart: typing.Optional[builtins.bool] = None,
-        compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
+        compute_network: typing.Optional[_cdktf_cdktf_provider_google_data_google_compute_network_6cd2ae20.DataGoogleComputeNetwork] = None,
         concurrent: typing.Optional[jsii.Number] = None,
         default_disk_size_gb: typing.Optional[jsii.Number] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
@@ -317,7 +322,7 @@ class GitlabRunnerAutoscalingProps:
         machine_type: typing.Optional[builtins.str] = None,
         network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         preemptible: typing.Optional[builtins.bool] = None,
-        service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
+        service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_compute_instance_template_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -338,7 +343,7 @@ class GitlabRunnerAutoscalingProps:
         :param tags: tags for the runner. Default: - ['runner', 'gitlab', 'awscdk']
         '''
         if isinstance(service_account, dict):
-            service_account = _cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount(**service_account)
+            service_account = _cdktf_cdktf_provider_google_compute_instance_template_6cd2ae20.ComputeInstanceTemplateServiceAccount(**service_account)
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__c88032eb7bd25ee0d2ad0139ad567354349b2287562f65346004517f962685e3)
             check_type(argname="argument gitlab_token", value=gitlab_token, expected_type=type_hints["gitlab_token"])
@@ -400,11 +405,11 @@ class GitlabRunnerAutoscalingProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def provider(self) -> _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider:
+    def provider(self) -> _cdktf_cdktf_provider_google_provider_6cd2ae20.GoogleProvider:
         '''Google Cloud Provider.'''
         result = self._values.get("provider")
         assert result is not None, "Required property 'provider' is missing"
-        return typing.cast(_cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider, result)
+        return typing.cast(_cdktf_cdktf_provider_google_provider_6cd2ae20.GoogleProvider, result)
 
     @builtins.property
     def automatic_restart(self) -> typing.Optional[builtins.bool]:
@@ -420,7 +425,7 @@ class GitlabRunnerAutoscalingProps:
     @builtins.property
     def compute_network(
         self,
-    ) -> typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork]:
+    ) -> typing.Optional[_cdktf_cdktf_provider_google_data_google_compute_network_6cd2ae20.DataGoogleComputeNetwork]:
         '''VPC for the Gitlab Runner .
 
         :default: - A new VPC will be created.
@@ -434,7 +439,7 @@ class GitlabRunnerAutoscalingProps:
             new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', computeNetwork: computeNetwork });
         '''
         result = self._values.get("compute_network")
-        return typing.cast(typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork], result)
+        return typing.cast(typing.Optional[_cdktf_cdktf_provider_google_data_google_compute_network_6cd2ae20.DataGoogleComputeNetwork], result)
 
     @builtins.property
     def concurrent(self) -> typing.Optional[jsii.Number]:
@@ -545,10 +550,10 @@ class GitlabRunnerAutoscalingProps:
     @builtins.property
     def service_account(
         self,
-    ) -> typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount]:
+    ) -> typing.Optional[_cdktf_cdktf_provider_google_compute_instance_template_6cd2ae20.ComputeInstanceTemplateServiceAccount]:
         '''The Service Account to be used by the Gitlab Runner.'''
         result = self._values.get("service_account")
-        return typing.cast(typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount], result)
+        return typing.cast(typing.Optional[_cdktf_cdktf_provider_google_compute_instance_template_6cd2ae20.ComputeInstanceTemplateServiceAccount], result)
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -592,9 +597,9 @@ def _typecheckingstub__033f891cb05a9b920c1fe5001270de7f0ace57003ad62a8457ef21531
     id: builtins.str,
     *,
     gitlab_token: builtins.str,
-    provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
+    provider: _cdktf_cdktf_provider_google_provider_6cd2ae20.GoogleProvider,
     automatic_restart: typing.Optional[builtins.bool] = None,
-    compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
+    compute_network: typing.Optional[_cdktf_cdktf_provider_google_data_google_compute_network_6cd2ae20.DataGoogleComputeNetwork] = None,
     concurrent: typing.Optional[jsii.Number] = None,
     default_disk_size_gb: typing.Optional[jsii.Number] = None,
     desired_capacity: typing.Optional[jsii.Number] = None,
@@ -604,7 +609,7 @@ def _typecheckingstub__033f891cb05a9b920c1fe5001270de7f0ace57003ad62a8457ef21531
     machine_type: typing.Optional[builtins.str] = None,
     network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     preemptible: typing.Optional[builtins.bool] = None,
-    service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
+    service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_compute_instance_template_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
     tags: typing.Optional[typing.Sequence[builtins.str]] = None,
 ) -> None:
     """Type checking stubs"""
@@ -613,9 +618,9 @@ def _typecheckingstub__033f891cb05a9b920c1fe5001270de7f0ace57003ad62a8457ef21531
 def _typecheckingstub__c88032eb7bd25ee0d2ad0139ad567354349b2287562f65346004517f962685e3(
     *,
     gitlab_token: builtins.str,
-    provider: _cdktf_cdktf_provider_google_6cd2ae20.GoogleProvider,
+    provider: _cdktf_cdktf_provider_google_provider_6cd2ae20.GoogleProvider,
     automatic_restart: typing.Optional[builtins.bool] = None,
-    compute_network: typing.Optional[_cdktf_cdktf_provider_google_6cd2ae20.DataGoogleComputeNetwork] = None,
+    compute_network: typing.Optional[_cdktf_cdktf_provider_google_data_google_compute_network_6cd2ae20.DataGoogleComputeNetwork] = None,
     concurrent: typing.Optional[jsii.Number] = None,
     default_disk_size_gb: typing.Optional[jsii.Number] = None,
     desired_capacity: typing.Optional[jsii.Number] = None,
@@ -625,7 +630,7 @@ def _typecheckingstub__c88032eb7bd25ee0d2ad0139ad567354349b2287562f65346004517f9
     machine_type: typing.Optional[builtins.str] = None,
     network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     preemptible: typing.Optional[builtins.bool] = None,
-    service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
+    service_account: typing.Optional[typing.Union[_cdktf_cdktf_provider_google_compute_instance_template_6cd2ae20.ComputeInstanceTemplateServiceAccount, typing.Dict[builtins.str, typing.Any]]] = None,
     tags: typing.Optional[typing.Sequence[builtins.str]] = None,
 ) -> None:
     """Type checking stubs"""
