@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -16,9 +19,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdktf-gitlab-runner",
-    "0.0.751",
+    "0.0.881",
     __name__[0:-6],
-    "cdktf-gitlab-runner@0.0.751.jsii.tgz",
+    "cdktf-gitlab-runner@0.0.881.jsii.tgz",
 )
 
 __all__ = [
